"use client"
import { useRouter } from "next/navigation"
import Link from "next/link"
import { ArrowLeft, Clock, FileQuestion, Info } from "lucide-react"
import NavBar from "@/components/nav-bar"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card"
import { Alert, AlertDescription } from "@/components/ui/alert"
import { simulationLevels, getSimulationsByLevel } from "@/data/simulations"
import type { Simulation } from "@/data/simulations/debutant"

export default function SimulationLevelPage({ params }: { params: { level: string } }) {
  const router = useRouter()
  const levelId = params.level

  const level = simulationLevels.find((l) => l.id === levelId)
  const simulations = getSimulationsByLevel(levelId)

  if (!level) {
    return (
      <div className="min-h-screen bg-gray-50 flex items-center justify-center">
        <div className="text-center">
          <h1 className="text-2xl font-bold mb-4">Niveau de simulation non trouvé</h1>
          <Link href="/simulations" passHref>
            <Button>Retour aux simulations</Button>
          </Link>
        </div>
      </div>
    )
  }

  return (
    <div className="min-h-screen bg-gray-50">
 

      {/* En-tête de la page */}
      <div className={`py-12 text-white bg-gradient-to-r from-[#3d53b6] to-[#1da7f3]`}>
        <div className="container mx-auto px-4">
          <Link href="/simulations" className="inline-flex items-center text-white mb-6 hover:underline">
            <ArrowLeft className="mr-2 h-4 w-4" />
            Retour aux simulations
          </Link>
          <div className="flex items-center mb-4">
            <span className="text-4xl mr-3">{level.icon}</span>
            <h1 className="text-3xl font-bold">{level.title}</h1>
          </div>
          <p className="text-lg max-w-3xl">{level.description}</p>
        </div>
      </div>

      {/* Contenu principal */}
      <div className="container mx-auto px-4 py-12">
        {/* Alerte d'information */}
        <Alert className="mb-8 border-[#1da7f3] bg-[#1da7f3]/10">
          <Info className="h-5 w-5 text-[#1da7f3]" />
          <AlertDescription className="ml-2">
            Choisissez une simulation pour commencer. Vous pouvez passer d'une question à l'autre et revenir en arrière
            pendant l'examen.
          </AlertDescription>
        </Alert>

        {/* Liste des simulations */}
        <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-6">
          {simulations.map((simulation: Simulation) => (
            <Card key={simulation.id} className="border-2 hover:border-[#3d53b6] transition-all duration-300">
              <CardHeader>
                <CardTitle>{simulation.title}</CardTitle>
                <CardDescription>{simulation.description}</CardDescription>
              </CardHeader>
              <CardContent>
                <div className="flex flex-col space-y-3">
                  <div className="flex items-center">
                    <FileQuestion className="h-5 w-5 text-gray-500 mr-2" />
                    <span className="text-sm text-gray-700">{simulation.questions.length} questions</span>
                  </div>
                  <div className="flex items-center">
                    <Clock className="h-5 w-5 text-gray-500 mr-2" />
                    <span className="text-sm text-gray-700">{simulation.duration} minutes</span>
                  </div>
                </div>
              </CardContent>
              <CardFooter>
                <Link href={`/simulations/${levelId}/${simulation.id}`} passHref>
                  <Button className={`w-full ${level.buttonColor} text-white`}>Commencer la simulation</Button>
                </Link>
              </CardFooter>
            </Card>
          ))}
        </div>
      </div>
    </div>
  )
}
